from sl_ai_models.gpt4ovision import Gpt4oVision
from sl_ai_models.gpt4o import Gpt4o
from sl_ai_models.perplexity import Perplexity
from sl_ai_models.claude35sonnet import Claude35Sonnet
from sl_ai_models.exa_searcher import ExaSearcher
from sl_ai_models.gpt4omini import Gpt4oMini
from sl_ai_models.deepgram_nova2 import DeepgramNova2
from sl_ai_models.claude3opus import Claude3Opus
from sl_ai_models.gpt35_scrape_cleaning import Gpt35ScrapeCleaning
from sl_ai_models.gpt35_internet_archive_8pc import Gpt35InternetArchive8PC

from sl_ai_models.resource_managers.monetary_cost_manager import MonetaryCostManager

from sl_ai_models.utils.ai_misc import clean_indents


from typing import Final
from sl_ai_models.model_archetypes.openai_text_model import OpenAiTextToTextModel
from sl_ai_models.utils.ai_misc import clean_indents  # Keep this import here for easier imports into other files so prompts can keep proper indentation levels in code # NOSONAR

class Gpt35ScrapeCleaning(OpenAiTextToTextModel):
    # See OpenAI Limit on the account dashboard for most up-to-date limit
    MODEL_NAME: Final[str] = "ft:gpt-3.5-turbo-1106:internet-archive:scraping-cleaner:8gpVxefq"
    REQUESTS_PER_PERIOD_LIMIT: Final[int] = 9_000
    REQUEST_PERIOD_IN_SECONDS: Final[int] = 60
    TIMEOUT_TIME: Final[int] = 40
    TOKENS_PER_PERIOD_LIMIT: Final[int] = 8_000_000
    TOKEN_PERIOD_IN_SECONDS: Final[int] = 60
